@@ -26,7 +26,10 @@ class Commander:
                 if arg.default != arg.empty:
                     _default = arg.default
                 if not _default:
-                    func_args_parser.add_argument(arg.name, type=_type)
+                    if _type == list:
+                        func_args_parser.add_argument(f'-{arg.name}', type=str, nargs='+')
+                    else:
+                        func_args_parser.add_argument(arg.name, type=_type)
                 else:
                     func_args_parser.add_argument(f'--{arg.name}', required=False, type=_type, default=_default)
             self.command_table[func_name] = {'func': func, 'analyser': func_analyser, 'parser': func_args_parser}
@@ -72,13 +75,15 @@ class Commander:
                 f"{i}:{self.command_table[i]['func'].__doc__.strip().split(':param')[0].strip() if self.command_table[i]['func'].__doc__ else 'NONE'}"
                 for i in self.command_table
             ]
-            return '\n'.join((ls if len(ls) > 1 else []) + ["--help:应用帮助" if user_lang == 'zh' else '--help:Application help'])
+            return '\n'.join(
+                (ls if len(ls) > 1 else []) + ["--help:应用帮助" if user_lang == 'zh' else '--help:Application help']
+            )
         if len(self.command_table) > 1:
             call_func = route_path[0]
             has_args = [i.strip().strip('--') for i in route_path[1:]]
         else:
             call_func = list(self.command_table.keys())[0]
-            has_args = [i.strip().strip('--') for i in route_path[1:]]
+            has_args = [i.strip().strip('--') for i in route_path]
         if call_func not in self.command_table:
             return '错误:无该命令' if user_lang != 'zh' else 'ERROR:No such command'
         call_analyser = self.command_table[call_func]['analyser']
@@ -99,6 +104,8 @@ class Commander:
     def __call__(self):
         if len(sys.argv) >= 2:
             if sys.argv[1] == '--qrun-commander-complete':
+                if 'qrun' in sys.argv:
+                    sys.argv.remove('qrun')
                 return print(self.__command_complete__(sys.argv[2:]))
             if sys.argv[1] == '--help':
                 return self.help()
@@ -114,7 +121,9 @@ class Commander:
                 func_name = sys.argv[1]
                 sys.argv = sys.argv[:1] + sys.argv[2:]
             except IndexError:
-                return QproDefaultConsole.print(QproErrorString, '至少输入一个子命令!' if user_lang == 'zh' else 'Input at least one sub command!')
+                return QproDefaultConsole.print(
+                    QproErrorString, '至少输入一个子命令!' if user_lang == 'zh' else 'Input at least one sub command!'
+                )
             else:
                 func_info = self.command_table[func_name]
                 args = func_info['parser'].parse_args()
@@ -133,5 +142,7 @@ class Commander:
         :return:
         """
         if func_name not in self.command_table:
-            return QproDefaultConsole.print(QproErrorString,  f'{func_name} 未被注册!' if user_lang == 'zh' else f'{func_name} not registered!')
+            return QproDefaultConsole.print(
+                QproErrorString,  f'{func_name} 未被注册!' if user_lang == 'zh' else f'{func_name} not registered!'
+            )
         return self.command_table[func_name]['func'](*args, **kwargs)
